@@ -92,11 +92,11 @@ class TestPolycrystal(unittest.TestCase):
                 subsum = np.sum(diffraction_pattern[i - w:i + w, j - w:j + w])
                 self.assertGreaterEqual(subsum, 0)
 
-        # Scatterers should be confined to rings
+        # ScatteringUnits should be confined to rings
         bragg_angles = []
-        for scatterer in self.detector.frames[0]:
-            kprime = scatterer.scattered_wave_vector
-            k = scatterer.incident_wave_vector
+        for scattering_unit in self.detector.frames[0]:
+            kprime = scattering_unit.scattered_wave_vector
+            k = scattering_unit.incident_wave_vector
             normfactor = np.linalg.norm(k) * np.linalg.norm(kprime)
             tth = np.arccos(np.dot(k, kprime) / normfactor)
             bragg_angles.append(tth / 2.)
@@ -124,13 +124,13 @@ class TestPolycrystal(unittest.TestCase):
                 'data'),
             'my_polycrystal')
         self.polycrystal.save(path, save_mesh_as_xdmf=True)
-        self.polycrystal = Polycrystal.load(path)
+        self.polycrystal = Polycrystal.load(path+'.pc')
         self.assertTrue(
             np.allclose(
                 orientation_lab,
                 self.polycrystal.orientation_lab),
             msg='Data corrupted on save and load')
-        os.remove(path)
+        os.remove(path + '.pc')
         os.remove(path + ".xdmf")
         os.remove(path + ".h5")
 
