@@ -1,6 +1,7 @@
-"""The ``templates`` module allows for fast creation of a few select sample types and diffraction geometries without having to 
-worry about any of the "under the hood" scripting."""
-#TODO: Review docs.
+"""The ``templates`` module allows for fast creation of a few select sample types and diffraction geometries without having to
+worry about any of the "under the hood" scripting.
+
+"""
 import numpy as np
 import pygalmesh
 from scipy.spatial.transform import Rotation
@@ -82,60 +83,6 @@ def s3dxrd(parameters):
 
     return beam, detector, motion
 
-
-def _get_motion_from_params(parameters):
-    """Produce a ``xrd_simulator.motion.RigidBodyMotion`` from the s3dxrd params dictionary.
-    """
-    translation = np.array([0., 0., 0.])
-    return RigidBodyMotion(
-        parameters["rotation_axis"],
-        parameters["rotation_step"],
-        translation)
-
-
-def _get_beam_from_params(parameters):
-    """Produce a ``xrd_simulator.beam.Beam`` from the s3dxrd params dictionary.
-    """
-    dz = parameters['beam_side_length_z'] / 2.
-    dy = parameters['beam_side_length_y'] / 2.
-    beam_vertices = np.array([
-        [-parameters['detector_distance'], -dy, -dz],
-        [-parameters['detector_distance'], dy, -dz],
-        [-parameters['detector_distance'], -dy, dz],
-        [-parameters['detector_distance'], dy, dz],
-        [parameters['detector_distance'], -dy, -dz],
-        [parameters['detector_distance'], dy, -dz],
-        [parameters['detector_distance'], -dy, dz],
-        [parameters['detector_distance'], dy, dz]
-    ])
-
-    beam_direction = np.array([1.0, 0.0, 0.0])
-    polarization_vector = np.array([0.0, 1.0, 0.0])
-
-    return Beam(
-        beam_vertices,
-        beam_direction,
-        parameters['wavelength'],
-        polarization_vector)
-
-
-def _get_detector_from_params(parameters):
-    """Produce a ``xrd_simulator.detector.Detector`` from the s3dxrd params dictionary.
-    """
-
-    p_z, p_y = parameters['pixel_side_length_z'], parameters['pixel_side_length_y']
-    det_dist = parameters['detector_distance']
-    det_pix_y = parameters['number_of_detector_pixels_y']
-    det_pix_z = parameters['number_of_detector_pixels_z']
-    det_cz, det_cy = parameters['detector_center_pixel_z'], parameters['detector_center_pixel_y']
-
-    d_0 = np.array([det_dist, -det_cy * p_y, -det_cz * p_z])
-    d_1 = np.array([det_dist, (det_pix_y - det_cy) * p_y, -det_cz * p_z])
-    d_2 = np.array([det_dist, -det_cy * p_y, (det_pix_z - det_cz) * p_z])
-
-    return Detector(p_z, p_y, d_0, d_1, d_2)
-
-
 def polycrystal_from_odf(orientation_density_function,
                          number_of_crystals,
                          sample_bounding_cylinder_height,
@@ -171,6 +118,8 @@ def polycrystal_from_odf(orientation_density_function,
             [a,b,c,alpha,beta,gamma], where alpha,beta and gamma are in units of degrees while
             a,b and c are in units of anstrom.
         sgname (:obj:`string`): Name of space group , e.g 'P3221' for quartz, SiO2, for instance
+        path_to_cif_file (:obj:`string`): Path to CIF file. Defaults to None, in which case no structure
+            factors are computed.
         maximum_sampling_bin_seperation (:obj:`float`): Discretization steplength of orientation
             space using spherical coordinates over the unit quarternions in units of radians.
             A smaller steplength gives more accurate sampling of the input
@@ -230,6 +179,107 @@ def polycrystal_from_odf(orientation_density_function,
         phases=phases,
         element_phase_map=element_phase_map)
 
+def get_uniform_powder_sample(
+        sample_bounding_radius,
+        number_of_grains,
+        unit_cell,
+        sgname,
+        strain_tensor=np.zeros((3, 3)),
+        path_to_cif_file=None):
+    """Generate a polycyrystal with grains overlayed at the origin and orientations drawn uniformly.
+
+    Args:
+        sample_bounding_radius (:obj:`float`): Bounding radius of sample. All tetrahedral crystal
+            elements will be overlayed within a sphere of ``sample_bounding_radius`` radius.
+        number_of_grains (:obj:`int`): Number of grains composing the polycrystal sample.
+        unit_cell (:obj:`list` of :obj:`float`): Crystal unit cell representation of the form
+            [a,b,c,alpha,beta,gamma], where alpha,beta and gamma are in units of degrees while
+            a,b and c are in units of anstrom.
+        sgname (:obj:`string`):  Name of space group , e.g 'P3221' for quartz, SiO2, for instance
+        strain_tensor (:obj:`numpy array`): Strain tensor to apply to all tetrahedral crystal
+            elements contained within the sample. ``shape=(3,3)``.
+        path_to_cif_file (:obj:`string`): Path to CIF file. Defaults to None, in which case no structure
+            factors are computed.
+
+    Returns:
+        (:obj:`xrd_simulator.polycrystal`) A polycyrystal sample with ``number_of_grains`` grains.
+
+    Examples:
+        .. literalinclude:: examples/example_get_uniform_powder_sample.py
+
+    """
+    coord, enod, node_number = [], [], 0
+    r = sample_bounding_radius
+    for _ in range(number_of_grains):
+        coord.append([r / np.sqrt(3.), r / np.sqrt(3.), -r / np.sqrt(3.)])
+        coord.append([r / np.sqrt(3.), -r / np.sqrt(3.), -r / np.sqrt(3.)])
+        coord.append([-r / np.sqrt(2.), 0, -r / np.sqrt(2.)])
+        coord.append([0, 0, r])
+        enod.append(list(range(node_number, node_number + 4)))
+        node_number += 3
+    coord, enod = np.array(coord), np.array(enod)
+    mesh = TetraMesh.generate_mesh_from_vertices(coord, enod)
+    orientation = Rotation.random(mesh.number_of_elements).as_matrix()
+    element_phase_map = np.zeros((mesh.number_of_elements,)).astype(int)
+    phases = [Phase(unit_cell, sgname, path_to_cif_file)]
+    return Polycrystal(
+        mesh,
+        orientation,
+        strain=strain_tensor,
+        phases=phases,
+        element_phase_map=element_phase_map)
+
+def _get_motion_from_params(parameters):
+    """Produce a ``xrd_simulator.motion.RigidBodyMotion`` from the s3dxrd params dictionary.
+    """
+    translation = np.array([0., 0., 0.])
+    return RigidBodyMotion(
+        parameters["rotation_axis"],
+        parameters["rotation_step"],
+        translation)
+
+
+def _get_beam_from_params(parameters):
+    """Produce a ``xrd_simulator.beam.Beam`` from the s3dxrd params dictionary.
+    """
+    dz = parameters['beam_side_length_z'] / 2.
+    dy = parameters['beam_side_length_y'] / 2.
+    beam_vertices = np.array([
+        [-parameters['detector_distance'], -dy, -dz],
+        [-parameters['detector_distance'], dy, -dz],
+        [-parameters['detector_distance'], -dy, dz],
+        [-parameters['detector_distance'], dy, dz],
+        [parameters['detector_distance'], -dy, -dz],
+        [parameters['detector_distance'], dy, -dz],
+        [parameters['detector_distance'], -dy, dz],
+        [parameters['detector_distance'], dy, dz]
+    ])
+
+    beam_direction = np.array([1.0, 0.0, 0.0])
+    polarization_vector = np.array([0.0, 1.0, 0.0])
+
+    return Beam(
+        beam_vertices,
+        beam_direction,
+        parameters['wavelength'],
+        polarization_vector)
+
+
+def _get_detector_from_params(parameters):
+    """Produce a ``xrd_simulator.detector.Detector`` from the s3dxrd params dictionary.
+    """
+
+    p_z, p_y = parameters['pixel_side_length_z'], parameters['pixel_side_length_y']
+    det_dist = parameters['detector_distance']
+    det_pix_y = parameters['number_of_detector_pixels_y']
+    det_pix_z = parameters['number_of_detector_pixels_z']
+    det_cz, det_cy = parameters['detector_center_pixel_z'], parameters['detector_center_pixel_y']
+
+    d_0 = np.array([det_dist, -det_cy * p_y, -det_cz * p_z])
+    d_1 = np.array([det_dist, (det_pix_y - det_cy) * p_y, -det_cz * p_z])
+    d_2 = np.array([det_dist, -det_cy * p_y, (det_pix_z - det_cz) * p_z])
+
+    return Detector(p_z, p_y, d_0, d_1, d_2)
 
 def _sample_ODF(ODF, maximum_sampling_bin_seperation, coordinates):
     """Draw orientation matrices form an ODF at spatial locations ``coordinates``.
@@ -310,54 +360,3 @@ def _sample_ODF(ODF, maximum_sampling_bin_seperation, coordinates):
             q_pertubated).as_matrix().reshape(3, 3))
 
     return np.array(rotations)
-
-
-def get_uniform_powder_sample(
-        sample_bounding_radius,
-        number_of_grains,
-        unit_cell,
-        sgname,
-        strain_tensor=np.zeros((3, 3)),
-        path_to_cif_file=None):
-    """Generate a polycyrystal with grains overlayed at the origin and orientations drawn uniformly.
-
-    Args:
-        sample_bounding_radius (:obj:`float`): Bounding radius of sample. All tetrahedral crystal
-            elements will be overlayed within a sphere of ``sample_bounding_radius`` radius.
-        number_of_grains (:obj:`int`): Number of grains composing the polycrystal sample.
-        unit_cell (:obj:`list` of :obj:`float`): Crystal unit cell representation of the form
-            [a,b,c,alpha,beta,gamma], where alpha,beta and gamma are in units of degrees while
-            a,b and c are in units of anstrom.
-        sgname (:obj:`string`):  Name of space group , e.g 'P3221' for quartz, SiO2, for instance
-        strain_tensor (:obj:`numpy array`): Strain tensor to apply to all tetrahedral crystal
-            elements contained within the sample. ``shape=(3,3)``.
-        path_to_cif_file (:obj:`string`): Path to CIF file. Defaults to None, in which case no structure
-            factors are computed, i.e `structure_factors=None`.
-
-    Returns:
-        (:obj:`xrd_simulator.polycrystal`) A polycyrystal sample with ``number_of_grains`` grains.
-
-    Examples:
-        .. literalinclude:: examples/example_get_uniform_powder_sample.py
-
-    """
-    coord, enod, node_number = [], [], 0
-    r = sample_bounding_radius
-    for _ in range(number_of_grains):
-        coord.append([r / np.sqrt(3.), r / np.sqrt(3.), -r / np.sqrt(3.)])
-        coord.append([r / np.sqrt(3.), -r / np.sqrt(3.), -r / np.sqrt(3.)])
-        coord.append([-r / np.sqrt(2.), 0, -r / np.sqrt(2.)])
-        coord.append([0, 0, r])
-        enod.append(list(range(node_number, node_number + 4)))
-        node_number += 3
-    coord, enod = np.array(coord), np.array(enod)
-    mesh = TetraMesh.generate_mesh_from_vertices(coord, enod)
-    orientation = Rotation.random(mesh.number_of_elements).as_matrix()
-    element_phase_map = np.zeros((mesh.number_of_elements,)).astype(int)
-    phases = [Phase(unit_cell, sgname, path_to_cif_file)]
-    return Polycrystal(
-        mesh,
-        orientation,
-        strain=strain_tensor,
-        phases=phases,
-        element_phase_map=element_phase_map)
